# QA

Types:

```python
from isaacus.types.extractions.qa import AnswerExtractionResponse
```

Methods:

- <code title="post /extractions/qa">client.extractions.qa.<a href="./src/isaacus/resources/extractions/qa/qa.py">create</a>(\*\*<a href="src/isaacus/types/extractions/qa/qa_create_params.py">params</a>) -> <a href="./src/isaacus/types/extractions/qa/answer_extraction_response.py">AnswerExtractionResponse</a></code>
